/* Stochastic Momentum Index

The Stochastic Momentum Index was developed by William Blau as introduced in the in the January 1993 issue 
of Technical Analysis of Stocks & Commodities. While similar to the Stochastic Oscillator, the SMI displays 
where the close is relative to the midpoint of the recent high/low range, as compared to the close relative
to the recent high/low with the Stochastic Oscillator. This results is an oscillator that ranges between -100
and +100 and can be a bit less erratic than an equal period Stochastic Oscillator.

The oscillator is comprised of two lines, the SMI (blue) and the moving average of the SMI (red).
When the close is greater than the midpoint of the range, the SMI will be positive.
When the close is less than the midpoint of the range, it will be negative. 
The interpretation of the SMI is virtually identical to that of the Stochastic Oscillator. 
The most basic pattern to trade from is to buy when the SMI falls below -40 and then returns above it.
Sell when the SMI rises above +40 and then falls back below that level. 
Another trading signal is buy when the SMI rises above the moving average, and sell when the SMI falls below the moving average.
As always, before basing any trades on strict overbought / oversold levels it is recommended that one first qualify
the trendiness of the market using an indicator such as R-Squared. 
If indicators suggest a non-trending market, then trades based on strict overbought/oversold levels should produce the best results.

Original Indicator is not mine.  

Fine Tuned by Linuxser , August, 2007 for TSD  http://www.forex-tsd.com/              

*/

#property copyright "Under The GNU General Public License"
#property link      "www.gnu.org"

#property indicator_separate_window
#property indicator_buffers 2
#property indicator_color1 LightSkyBlue
#property indicator_color2 Red
#property indicator_level1 0
#property indicator_level2 40
#property indicator_level3 -40
#property indicator_style1 0
#property indicator_style2 2
#property indicator_width1 2
#property indicator_width2 0

#property indicator_maximum 100
#property indicator_minimum -100

//---- input parameters
extern int       LookbackP=13;
extern int       SmoothingP=25;
extern int       DoubleSmoothingP=2;
extern int       Signal=3;
//---- buffers
double SMI_Buffer[];
double Signal_Buffer[];
double SM_Buffer[];
double EMA_SM[];
double EMA2_SM[];
double EMA_HQ[];
double EMA2_HQ[];
double HQ_Buffer[];
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
//---- indicators
   IndicatorBuffers(8);
   SetIndexStyle(0,DRAW_LINE);
   SetIndexBuffer(0,SMI_Buffer);
   SetIndexStyle(1,DRAW_LINE);
   SetIndexBuffer(1,Signal_Buffer);
   SetIndexLabel(0,"SMI");
   SetIndexLabel(1,"Signal SMI");
   SetIndexBuffer(2,SM_Buffer);
   SetIndexBuffer(3,EMA_SM);
   SetIndexBuffer(4,EMA2_SM);
   SetIndexBuffer(5,EMA_HQ);
   SetIndexBuffer(6,EMA2_HQ);
   SetIndexBuffer(7,HQ_Buffer);

   IndicatorShortName("SMI_v1("+LookbackP+","+SmoothingP+","+DoubleSmoothingP+","+Signal+")");
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custor indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//---- TODO: add your code here
   
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
  {
   int    counted_bars;
   int limit;
   int i;
   if(counted_bars<0) return(-1);
   limit=Bars-LookbackP-counted_bars;
   for (i=limit;i>=0;i--)
      {      
      HQ_Buffer[i]=High[Highest(NULL,0,MODE_HIGH,LookbackP,i)]-Low[Lowest(NULL,0,MODE_LOW,LookbackP,i)];
      SM_Buffer[i]=Close[i]-(High[Highest(NULL,0,MODE_HIGH,LookbackP,i)]+Low[Lowest(NULL,0,MODE_LOW,LookbackP,i)])/2;
      }
   for (i=limit-SmoothingP;i>=0;i--)
      {
      EMA_SM[i]=iMAOnArray(SM_Buffer,0,SmoothingP,0,MODE_EMA,i);
      EMA_HQ[i]=iMAOnArray(HQ_Buffer,0,SmoothingP,0,MODE_EMA,i);
      }
   for (i=limit-SmoothingP-DoubleSmoothingP;i>=0;i--)
      {
      EMA2_SM[i]=iMAOnArray(EMA_SM,0,DoubleSmoothingP,0,MODE_EMA,i);
      EMA2_HQ[i]=iMAOnArray(EMA_HQ,0,DoubleSmoothingP,0,MODE_EMA,i);
      }
   for (i=limit-SmoothingP-DoubleSmoothingP-Signal;i>=0;i--)
      {
      SMI_Buffer[i]=100*EMA2_SM[i]/0.5/EMA2_HQ[i];
      }
   for (i=limit-SmoothingP-DoubleSmoothingP;i>=0;i--)
      {
      Signal_Buffer[i]=iMAOnArray(SMI_Buffer,0,Signal,0,MODE_EMA,i);
      }
 
//----
   return(0);
  }
//+------------------------------------------------------------------+